.. include:: ../BADGES.rst

Command Line
============

Help::

    hydrotoolbox --help

about
~~~~~
.. program-output:: hydrotoolbox about --help
   :prompt:

baseflow_sep
~~~~~~~~~~~~
.. program-output:: hydrotoolbox baseflow_sep --help
   :prompt:

baseflow_sep boughton
---------------------
.. program-output:: hydrotoolbox baseflow_sep boughton --help
   :prompt:

baseflow_sep chapman
--------------------
.. program-output:: hydrotoolbox baseflow_sep chapman --help
   :prompt:

baseflow_sep cm
---------------
.. program-output:: hydrotoolbox baseflow_sep cm --help
   :prompt:

baseflow_sep eckhardt
---------------------
.. program-output:: hydrotoolbox baseflow_sep eckhardt --help
   :prompt:

baseflow_sep ewma
-----------------
.. program-output:: hydrotoolbox baseflow_sep ewma --help
   :prompt:

baseflow_sep five_day
---------------------
.. program-output:: hydrotoolbox baseflow_sep five_day --help
   :prompt:

baseflow_sep furey
------------------
.. program-output:: hydrotoolbox baseflow_sep furey --help
   :prompt:

baseflow_sep ihacres
--------------------
.. program-output:: hydrotoolbox baseflow_sep ihacres --help
   :prompt:

baseflow_sep lh
---------------
.. program-output:: hydrotoolbox baseflow_sep lh --help
   :prompt:

baseflow_sep strict
-------------------
.. program-output:: hydrotoolbox baseflow_sep strict --help
   :prompt:

baseflow_sep ukih
-----------------
.. program-output:: hydrotoolbox baseflow_sep ukih --help
   :prompt:

baseflow_sep usgs_hysep_fixed
-----------------------------
.. program-output:: hydrotoolbox baseflow_sep usgs_hysep_fixed --help
   :prompt:

baseflow_sep usgs_hysep_local
-----------------------------
.. program-output:: hydrotoolbox baseflow_sep usgs_hysep_local --help
   :prompt:

baseflow_sep usgs_hysep_slide
-----------------------------
.. program-output:: hydrotoolbox baseflow_sep usgs_hysep_slide --help
   :prompt:

baseflow_sep willems
--------------------
.. program-output:: hydrotoolbox baseflow_sep willems --help
   :prompt:

exceedance_time
~~~~~~~~~~~~~~~
.. program-output:: hydrotoolbox exceedance_time --help
   :prompt:

flow_duration
~~~~~~~~~~~~~
.. program-output:: hydrotoolbox flow_duration --help
   :prompt:

indices
~~~~~~~
.. program-output:: hydrotoolbox indices --help
   :prompt:

recession
~~~~~~~~~
.. program-output:: hydrotoolbox recession --help
   :prompt:

storm_events
~~~~~~~~~~~~
.. program-output:: hydrotoolbox storm_events --help
   :prompt:
